@@ -5,9 +5,9 @@ use warnings;
 
 use Error::Pure qw(err);
 use Mo qw(build default is);
-use Mo::utils qw(check_array_object check_number_of_items);
+use Mo::utils qw(check_array_object check_number check_number_of_items);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 has aliases => (
 	default => [],
@@ -19,6 +19,10 @@ has descriptions => (
 	is => 'ro',
 );
 
+has id => (
+	is => 'ro',
+);
+
 has labels => (
 	default => [],
 	is => 'ro',
@@ -37,6 +41,10 @@ has ns => (
 	is => 'ro',
 );
 
+has page_id => (
+	is => 'ro',
+);
+
 has sitelinks => (
 	default => [],
 	is => 'ro',
@@ -68,6 +76,9 @@ sub BUILD {
 		'Label');
 	check_number_of_items($self, 'labels', 'language', 'Label', 'language');
 
+	# Check page id.
+	check_number($self, 'page_id');
+
 	# Check sitelinks.
 	check_array_object($self, 'sitelinks', 'Wikibase::Datatype::Sitelink',
 		'Sitelink');
@@ -99,10 +110,12 @@ Wikibase::Datatype::Item - Wikibase item datatype.
  my $obj = Wikibase::Datatype::Item->new(%params);
  my $aliases_ar = $obj->aliases;
  my $descriptions_ar = $obj->descriptions;
+ my $id = $obj->id;
  my $labels_ar = $obj->labels;
  my $lastrevid = $obj->lastrevid;
  my $modified = $obj->modified;
  my $ns = $obj->ns;
+ my $page_id = $obj->page_id;
  my $sitelinks_ar = $obj->sitelinks;
  my $statements_ar = $obj->statements;
  my $title = $obj->title;
@@ -135,6 +148,11 @@ Item descriptions. One per language.
 Reference to array with Wikibase::Datatype::Value::Monolingual instances.
 Parameter is optional.
 
+=item * C<id>
+
+Id.
+Parameter is optional.
+
 =item * C<labels>
 
 Item descriptions. One per language.
@@ -156,6 +174,11 @@ Parameter is optional.
 Namespace.
 Default value is 0.
 
+=item * C<page_id>
+
+Page id. Numeric value.
+Parameter is optional.
+
 =item * C<sitelinks>
 
 Item sitelinks. One per site.
@@ -191,6 +214,14 @@ Get descriptions.
 
 Returns reference to array with Wikibase::Datatype::Value::Monolingual instances.
 
+=head2 C<id>
+
+ my $id = $obj->id;
+
+Get id.
+
+Returns string.
+
 =head2 C<labels>
 
  my $labels_ar = $obj->labels;
@@ -223,6 +254,14 @@ Get namespace.
 
 Returns number.
 
+=head2 C<page_id>
+
+ my $page_id = $obj->page_id;
+
+Get page id.
+
+Returns number.
+
 =head2 C<sitelinks>
 
  my $sitelinks_ar = $obj->sitelinks;
@@ -261,6 +300,8 @@ Returns string.
                  Parameter 'statements' must be a array.
                  Sitelink isn't 'Wikibase::Datatype::Sitelink' object.
                  Statement isn't 'Wikibase::Datatype::Statement' object.
+         From Mo::utils::check_page_id():
+                 Parameter 'page_id' must a number.
          From Mo::utils::check_number_of_items():
                  Sitelink for site '%s' has multiple values.
                  Description for language '%s' has multiple values.
@@ -415,6 +456,7 @@ Returns string.
                          'value' => 'English writer and humorist',
                  ),
          ],
+         'id' => 'Q42',
          'labels' => [
                  Wikibase::Datatype::Value::Monolingual->new(
                          'language' => 'cs',
@@ -425,6 +467,7 @@ Returns string.
                          'value' => 'Douglas Adams',
                  ),
          ],
+         'page_id' => 123,
          'sitelinks' => [
                  Wikibase::Datatype::Sitelink->new(
                          'site' => 'cswiki',
@@ -444,6 +487,8 @@ Returns string.
 
  # Print out.
  print "Title: ".$obj->title."\n";
+ print 'Id: '.$obj->id."\n";
+ print 'Page id: '.$obj->page_id."\n";
  print "Labels:\n";
  foreach my $label (sort { $a->language cmp $b->language } @{$obj->labels}) {
          print "\t".$label->value.' ('.$label->language.")\n";
@@ -481,6 +526,8 @@ Returns string.
 
  # Output:
  # Title: Q42
+ # Id: Q42
+ # Page id: 123
  # Labels:
  #         Douglas Adams (cs)
  #         Douglas Adams (en)
@@ -550,6 +597,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
